@@ -471,7 +471,7 @@ mod char_count {
     fn validate_exact_char_count_on_a_compliant_string() {
         let text = "I ❤ you";
         assert_eq!(text.len(), 9);
-        let original = text.clone();
+        let original = text;
 
         let result = text.validate("message", &CharCount::Exact(7)).result();
 
@@ -528,7 +528,7 @@ mod char_count {
     fn validate_max_char_count_on_a_compliant_string() {
         let text = "I ❤ you";
         assert_eq!(text.len(), 9);
-        let original = text.clone();
+        let original = text;
 
         let result = text.validate("message", &CharCount::Max(7)).result();
 
@@ -562,7 +562,7 @@ mod char_count {
     fn validate_min_char_count_on_a_compliant_string() {
         let text = "I ❤ you!";
         assert_eq!(text.len(), 10);
-        let original = text.clone();
+        let original = text;
 
         let result = text.validate("message", &CharCount::Min(8)).result();
 
@@ -596,7 +596,7 @@ mod char_count {
     fn validate_minmax_char_count_on_a_compliant_string() {
         let text = "I ❤ you";
         assert_eq!(text.len(), 9);
-        let original = text.clone();
+        let original = text;
 
         let result = text.validate("message", &CharCount::MinMax(6, 7)).result();
 
@@ -655,6 +655,7 @@ mod bound {
 
     proptest! {
         #[test]
+        #[allow(clippy::float_cmp)]
         fn validate_bound_exact_on_a_compliant_float_value(
             exact_bound in any::<f32>()
         ) {
@@ -905,6 +906,44 @@ mod bound {
     }
 }
 
+mod non_zero {
+    use super::*;
+
+    #[test]
+    fn validate_non_zero_on_a_double_that_is_zero() {
+        let field_value = 0f64;
+
+        let result = field_value.validate("field_value", &NonZero).result();
+
+        assert_eq!(
+            result,
+            Err(ValidationError {
+                message: None,
+                violations: vec![ConstraintViolation::Field(InvalidValue {
+                    code: "invalid-non-zero".into(),
+                    field: Field {
+                        name: "field_value".into(),
+                        actual: Some(Value::Double(field_value)),
+                        expected: None,
+                    }
+                })]
+            })
+        )
+    }
+
+    proptest! {
+        #[test]
+        #[allow(clippy::float_cmp)]
+        fn validate_non_zero_on_a_double_that_is_not_zero(
+            field_value in any::<f64>().prop_filter("non zero values", |v| *v != 0.)
+        ) {
+            let result = field_value.validate("field_value", &NonZero).result();
+
+            prop_assert_eq!(result.unwrap().unwrap(), field_value);
+        }
+    }
+}
+
 #[cfg(feature = "bigdecimal")]
 mod digits_bigdecimal {
     use super::*;
@@ -1070,7 +1109,7 @@ mod must_match {
                     },
                     field2: Field {
                         name: "repeated".into(),
-                        actual: Some(Value::String(input.clone() + &diff)),
+                        actual: Some(Value::String(input + &diff)),
                         expected: None,
                     },
                 })]
@@ -1336,3 +1375,54 @@ mod must_define_range_naive_date {
         }
     }
 }
+
+#[cfg(feature = "regex")]
+mod pattern {
+    use super::*;
+    use regex::Regex;
+
+    #[test]
+    fn validate_pattern_on_a_compliant_string() {
+        let email_address = "jane.doe@email.net".to_string();
+
+        let basic_email_pattern = Pattern(
+            Regex::new(r#"^[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,}$"#).expect("valid regex"),
+        );
+
+        let result = email_address
+            .validate("email_address", &basic_email_pattern)
+            .result();
+
+        assert_eq!(result.unwrap().unwrap(), "jane.doe@email.net");
+    }
+
+    #[test]
+    fn validate_pattern_on_a_not_compliant_string() {
+        let email_address = "jane*doe@email.net".to_string();
+
+        let basic_email_pattern = Pattern(
+            Regex::new(r#"^[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,}$"#).expect("valid regex"),
+        );
+
+        let result = email_address
+            .validate("email_address", &basic_email_pattern)
+            .result();
+
+        assert_eq!(
+            result.unwrap_err(),
+            ValidationError {
+                message: None,
+                violations: vec![ConstraintViolation::Field(InvalidValue {
+                    code: "invalid-pattern".into(),
+                    field: Field {
+                        name: "email_address".into(),
+                        actual: Some(Value::String("jane*doe@email.net".into())),
+                        expected: Some(Value::String(
+                            r#"^[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,}$"#.into()
+                        )),
+                    }
+                })]
+            }
+        );
+    }
+}
